"""Common utils."""

from .util import Util
from ._stringutil import StringBuilder

util = Util()

__author__ = "srg"
__version__ = "1.0.2"

__all__ = [
    'util'
]
